@@ -1,5 +1,6 @@
 from base64 import b64encode
 from requests import Session
+from .errors import EmptyImage, InvalidToken, ServerError, TooManyRequests
 
 class TraceMoe:
     """Tracemoe class with all the stuff"""
@@ -8,9 +9,17 @@ class TraceMoe:
         self.media_url = "https://media.trace.moe/"
         self.api_token = api_token
         self.r_session = Session()
-        self.r_session.headers = {
-            "Content-Type": "application/json"
-        }
+        self.r_session.headers = {"Content-Type": "application/json"}
+    
+    def get_me(self) -> dict:
+        """
+        Lets you check the search quota and limit for your account (or IP address).
+        Returns:
+          dict: response from server
+        """
+        url = f"{self.base_url}me"
+        if self.api_token: url += f"?token={self.token}"
+        return self.r_session.get(url).json()
     
     def search(self, path:str, encode:bool=True, is_url:bool=False) -> dict:
         """
@@ -19,27 +28,41 @@ class TraceMoe:
            encode: True if Img file name is given
            is_url: Treat the path as a url or not
         Returns:
-           json response
+           dict: response from server
+        Raises:
+           EmptyImage: Raised If Image Is empty
+           InvalidToken: Raised when token provided Is Invalid
+           ServerError: Raised If server Is having problem or Image Is malformed.
         """
         url = f"{self.base_url}api/search"
         if self.api_token:
             url += f"?token={self.api_token}"
 
         if is_url:
-            return self.r_session.get(
+            response = self.r_session.get(
                 url, params={"url": path}
             ).json()
 
         elif encode:
             with open(path, "rb") as f:
                 encoded = b64encode(f.read()).decode("utf-8")
-                return self.r_session.post(
+                response = self.r_session.post(
                 url, json={"image": encoded}
-                ).json()
+                )
         else:
-            return self.r_session.post(
+            response = self.r_session.post(
                 url, json={"image": encoded}
-                ).json()
+                )
+        if response.status_code == 200:
+            return response.json()
+        elif response.status_code == 400:
+            raise EmptyImage('Image provided was empty!')
+        elif response.status_code == 403:
+            raise InvalidToken('You are using Invalid token!')
+        elif response.status_code in [500, 503]:
+            raise ServerError('Image is malformed or Something went wrong')
+        elif response.status_code == 429:
+            raise TooManyRequests(response.text)
     
     def create_preview(self, json:dict, path:str, index:int = 0,) -> bytes:
         """
@@ -48,7 +71,7 @@ class TraceMoe:
            index: Which result to get
            path: Path to use, preview.php, thumbnail.php etc.
         Returns:
-           Image content
+           bytes: Video/Image content
         """
         json = json["docs"][index]
         url = f"{self.base_url}{path}?anilist_id={json['anilist_id']}"\
@@ -56,13 +79,23 @@ class TraceMoe:
         print(url)
         return self.r_session.get(url).content
     
+    def image_preview(self, json:dict, index:int = 0) -> bytes:
+        """
+        Args:
+           json: Python dict given by search
+           index: Which result to get
+        Returns:
+           bytes: Video content
+        """
+        return self.create_preview(json, 'thumbnail.php', index)
+    
     def video_preview(self, json:dict, index:int = 0) -> bytes:
         """
         Args:
            json: Python dict given by search
            index: Which result to get
         Returns:
-           Image content
+           bytes: Video content
         """
         return self.create_preview(json, 'preview.php', index)
         
